oc\_ocdm.graph.entities.bibliographic.reference\_pointer module
---------------------------------------------------------------

.. automodule:: oc_ocdm.graph.entities.bibliographic.reference_pointer
   :members:
   :undoc-members:
   :show-inheritance:
